import logging

import boto3

from cachetools import cached
from dbnd._core.errors import DatabandConfigError
from dbnd._core.plugin.dbnd_plugins import use_airflow_connections


logger = logging.getLogger(__name__)


@cached(cache={})
def get_boto_session():
    if use_airflow_connections():
        from dbnd_airflow_contrib.credentials_helper_aws import AwsCredentials

        aws_credentials = AwsCredentials()
        logger.debug(
            "getting aws credentials from airflow connection '%s'"
            % aws_credentials.aws_conn_id
        )
        return aws_credentials.get_credentials()[0]
    else:
        logger.debug(
            "getting aws credentials from from environment using boto3 default strategy"
        )
        session = boto3.session.Session()
        if not session.get_credentials():
            raise DatabandConfigError("AWS credentials not found")
        return session


@cached(cache={})
def get_boto_s3_resource():
    session = get_boto_session()
    return session.resource("s3")


@cached(cache={})
def get_boto_emr_client(region_name=None):
    return get_boto_session().client("emr", region_name=region_name)



import dbnd

from dbnd import register_config_cls
from dbnd._core.plugin.dbnd_plugins import is_plugin_enabled
from targets.fs import FileSystems, register_file_system


@dbnd.hookimpl
def dbnd_setup_plugin():
    # register configs
    from dbnd_aws.emr.emr_config import EmrConfig
    from dbnd_aws.env import AwsEnvConfig

    register_config_cls(EmrConfig)
    register_config_cls(AwsEnvConfig)

    if is_plugin_enabled("dbnd-docker"):
        from dbnd_aws.batch.aws_batch_ctrl import AwsBatchConfig

        register_config_cls(AwsBatchConfig)

    from dbnd_aws.fs import build_s3_fs_client

    register_file_system(FileSystems.s3, build_s3_fs_client)



from os import path

import setuptools

from setuptools.config import read_configuration


BASE_PATH = path.dirname(__file__)
CFG_PATH = path.join(BASE_PATH, "setup.cfg")

config = read_configuration(CFG_PATH)
version = config["metadata"]["version"]

setuptools.setup(
    name="dbnd-aws",
    package_dir={"": "src"},
    install_requires=[
        "dbnd==" + version,
        # otherwise airflow dependencies are broken
        "httplib2>=0.9.2",
        "boto3",
        "botocore",
        "s3fs",
    ],
    extras_require=dict(tests=["awscli"]),
    entry_points={"dbnd": ["dbnd-aws = dbnd_aws._plugin"]},
)
